==> kdebase-3.0.1.tar.bz2: kdebase-3.0.1/kicker/core/unhidetrigger.h <==
/*****************************************************************

Copyright (c) 2002 John Firebaugh <jfirebaugh@kde.org>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#ifndef __UnhideTrigger_h__
#define __UnhideTrigger_h__

// Fix compilation with --enable-final
#ifdef None
#undef None
#endif

#include <qobject.h>

class UnhideTrigger : public QObject
{
	Q_OBJECT
public:
	enum Trigger { None = 0, Top, TopRight, Right, BottomRight, Bottom, BottomLeft, Left, TopLeft };
	static UnhideTrigger* the();

	void setEnabled( bool enable );
	bool isEnabled() const;

signals:
	void triggerUnhide( UnhideTrigger::Trigger t );
private slots:
	void pollMouse();
private:
	UnhideTrigger();
	void emitTrigger( Trigger t );
	Trigger _lastTrigger;
	QTimer *_timer;
	int enabledCount;
};

#endif

==> kdebase-3.1.4.tar.bz2: kdebase-3.1.4/kicker/core/unhidetrigger.h <==
/*****************************************************************

Copyright (c) 2002 John Firebaugh <jfirebaugh@kde.org>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#ifndef __UnhideTrigger_h__
#define __UnhideTrigger_h__

// Fix compilation with --enable-final
#ifdef None
#undef None
#endif

#include <qobject.h>

class UnhideTrigger : public QObject
{
	Q_OBJECT
public:
	enum Trigger { None = 0, Top, TopRight, Right, BottomRight, Bottom, BottomLeft, Left, TopLeft };
	static UnhideTrigger* the();

	void setEnabled( bool enable );
	bool isEnabled() const;

signals:
	void triggerUnhide( UnhideTrigger::Trigger t, int XineramaScreen );
private slots:
	void pollMouse();
private:
	UnhideTrigger();
	void emitTrigger( Trigger t , int XineramaScreen);
	Trigger _lastTrigger;
	int _lastXineramaScreen;
	QTimer *_timer;
	int enabledCount;
};

#endif
